@@ -4,7 +4,7 @@ from pygments.lexer import RegexLexer, include, bygroups, using, this
 from pygments.style import Style
 from pygments.token import Error, Punctuation, Text, Comment, Operator, Keyword, Name, String, Number
 
-class PseudocodeStyle(Style):
+class PseudocodefrStyle(Style):
     """Custom Style for Pseudocode fr"""
     default_style = ""
     styles = {
@@ -16,12 +16,12 @@ class PseudocodeStyle(Style):
         String:                 'bg:#eee #111'
     }
 
-class PseudocodefrLexer(RegexLexer):
+class PseudocodefrLexer(RegexLexer, PseudocodefrStyle):
     '''
     A Pseudo code (fr) lexer
     '''
     name = 'Pseudocode'
-    aliases = ['pseudocode', 'pseudo', 'algorithm', 'algo']
+    aliases = ['pseudocode', 'pseudo', 'pseudofr', 'algorithme', 'algo']
     filenames = ['*.algo', '*.pseudocode']
     mimetypes = []
     flags = re.IGNORECASE
@@ -64,6 +64,7 @@ class PseudocodefrLexer(RegexLexer):
                  (r'\b(debut|début|fin|si|alors|sinon|fin[_ ]si|tant[ _]que|tantque|fin[ _]tantque|faire|répéter'
                   r'repeter|type|structure|fin[ _]structure|fonction|procédure|procedure|retourner|renvoyer|'
                   r'pour|fin[ _]pour|à|déclarations?|jusque|spécialise|specialise|comporte|super|public|privé|protégé|'
+                  r'afficher|saisir|allant|variant|de|'
                   r'classe'
                   r')\s*\b', Keyword),
 
